# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ast.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ast.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tast.proto\x12\nrappel.ast\"5\n\x07Program\x12*\n\tfunctions\x18\x01 \x03(\x0b\x32\x17.rappel.ast.FunctionDef\"|\n\x0b\x46unctionDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x02io\x18\x02 \x01(\x0b\x32\x12.rappel.ast.IoDecl\x12\x1f\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\x12\x1e\n\x04span\x18\x04 \x01(\x0b\x32\x10.rappel.ast.Span\"I\n\x06IoDecl\x12\x0e\n\x06inputs\x18\x01 \x03(\t\x12\x0f\n\x07outputs\x18\x02 \x03(\t\x12\x1e\n\x04span\x18\x03 \x01(\x0b\x32\x10.rappel.ast.Span\"R\n\x05\x42lock\x12)\n\nstatements\x18\x01 \x03(\x0b\x32\x15.rappel.ast.Statement\x12\x1e\n\x04span\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Span\"\xe5\x04\n\tStatement\x12,\n\nassignment\x18\x01 \x01(\x0b\x32\x16.rappel.ast.AssignmentH\x00\x12-\n\x0b\x61\x63tion_call\x18\x02 \x01(\x0b\x32\x16.rappel.ast.ActionCallH\x00\x12\x31\n\rspread_action\x18\x03 \x01(\x0b\x32\x18.rappel.ast.SpreadActionH\x00\x12\x33\n\x0eparallel_block\x18\x04 \x01(\x0b\x32\x19.rappel.ast.ParallelBlockH\x00\x12\'\n\x08\x66or_loop\x18\x05 \x01(\x0b\x32\x13.rappel.ast.ForLoopH\x00\x12.\n\x0b\x63onditional\x18\x06 \x01(\x0b\x32\x17.rappel.ast.ConditionalH\x00\x12+\n\ntry_except\x18\x07 \x01(\x0b\x32\x15.rappel.ast.TryExceptH\x00\x12-\n\x0breturn_stmt\x18\x08 \x01(\x0b\x32\x16.rappel.ast.ReturnStmtH\x00\x12)\n\texpr_stmt\x18\t \x01(\x0b\x32\x14.rappel.ast.ExprStmtH\x00\x12+\n\nbreak_stmt\x18\x0b \x01(\x0b\x32\x15.rappel.ast.BreakStmtH\x00\x12\x31\n\rcontinue_stmt\x18\x0c \x01(\x0b\x32\x18.rappel.ast.ContinueStmtH\x00\x12+\n\nwhile_loop\x18\r \x01(\x0b\x32\x15.rappel.ast.WhileLoopH\x00\x12\x1e\n\x04span\x18\n \x01(\x0b\x32\x10.rappel.ast.SpanB\x06\n\x04kind\"\x0b\n\tBreakStmt\"\x0e\n\x0c\x43ontinueStmt\">\n\nAssignment\x12\x0f\n\x07targets\x18\x01 \x03(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\"\x9b\x01\n\nActionCall\x12\x13\n\x0b\x61\x63tion_name\x18\x01 \x01(\t\x12!\n\x06kwargs\x18\x02 \x03(\x0b\x32\x11.rappel.ast.Kwarg\x12+\n\x08policies\x18\x03 \x03(\x0b\x32\x19.rappel.ast.PolicyBracket\x12\x18\n\x0bmodule_name\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_module_name\"n\n\x0cSpreadAction\x12$\n\ncollection\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x10\n\x08loop_var\x18\x02 \x01(\t\x12&\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x16.rappel.ast.ActionCall\"0\n\rParallelBlock\x12\x1f\n\x05\x63\x61lls\x18\x01 \x03(\x0b\x32\x10.rappel.ast.Call\"f\n\x04\x43\x61ll\x12(\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x16.rappel.ast.ActionCallH\x00\x12,\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x18.rappel.ast.FunctionCallH\x00\x42\x06\n\x04kind\"g\n\x07\x46orLoop\x12\x11\n\tloop_vars\x18\x01 \x03(\t\x12\"\n\x08iterable\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\x12%\n\nblock_body\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\"W\n\tWhileLoop\x12#\n\tcondition\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12%\n\nblock_body\x18\x02 \x01(\x0b\x32\x11.rappel.ast.Block\"\xa7\x01\n\x0b\x43onditional\x12\'\n\tif_branch\x18\x01 \x01(\x0b\x32\x14.rappel.ast.IfBranch\x12-\n\relif_branches\x18\x02 \x03(\x0b\x32\x16.rappel.ast.ElifBranch\x12\x30\n\x0b\x65lse_branch\x18\x03 \x01(\x0b\x32\x16.rappel.ast.ElseBranchH\x00\x88\x01\x01\x42\x0e\n\x0c_else_branch\"v\n\x08IfBranch\x12#\n\tcondition\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x1e\n\x04span\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Span\x12%\n\nblock_body\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\"x\n\nElifBranch\x12#\n\tcondition\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x1e\n\x04span\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Span\x12%\n\nblock_body\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\"S\n\nElseBranch\x12\x1e\n\x04span\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Span\x12%\n\nblock_body\x18\x02 \x01(\x0b\x32\x11.rappel.ast.Block\"^\n\tTryExcept\x12+\n\x08handlers\x18\x02 \x03(\x0b\x32\x19.rappel.ast.ExceptHandler\x12$\n\ttry_block\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\"\x9d\x01\n\rExceptHandler\x12\x17\n\x0f\x65xception_types\x18\x01 \x03(\t\x12\x1e\n\x04span\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Span\x12%\n\nblock_body\x18\x03 \x01(\x0b\x32\x11.rappel.ast.Block\x12\x1a\n\rexception_var\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_exception_var\"<\n\nReturnStmt\x12$\n\x05value\x18\x01 \x01(\x0b\x32\x10.rappel.ast.ExprH\x00\x88\x01\x01\x42\x08\n\x06_value\"*\n\x08\x45xprStmt\x12\x1e\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\"\xb4\x04\n\x04\x45xpr\x12&\n\x07literal\x18\x01 \x01(\x0b\x32\x13.rappel.ast.LiteralH\x00\x12(\n\x08variable\x18\x02 \x01(\x0b\x32\x14.rappel.ast.VariableH\x00\x12)\n\tbinary_op\x18\x03 \x01(\x0b\x32\x14.rappel.ast.BinaryOpH\x00\x12\'\n\x08unary_op\x18\x04 \x01(\x0b\x32\x13.rappel.ast.UnaryOpH\x00\x12$\n\x04list\x18\x05 \x01(\x0b\x32\x14.rappel.ast.ListExprH\x00\x12$\n\x04\x64ict\x18\x06 \x01(\x0b\x32\x14.rappel.ast.DictExprH\x00\x12(\n\x05index\x18\x07 \x01(\x0b\x32\x17.rappel.ast.IndexAccessH\x00\x12$\n\x03\x64ot\x18\x08 \x01(\x0b\x32\x15.rappel.ast.DotAccessH\x00\x12\x31\n\rfunction_call\x18\t \x01(\x0b\x32\x18.rappel.ast.FunctionCallH\x00\x12-\n\x0b\x61\x63tion_call\x18\n \x01(\x0b\x32\x16.rappel.ast.ActionCallH\x00\x12\x31\n\rparallel_expr\x18\x0c \x01(\x0b\x32\x18.rappel.ast.ParallelExprH\x00\x12-\n\x0bspread_expr\x18\r \x01(\x0b\x32\x16.rappel.ast.SpreadExprH\x00\x12\x1e\n\x04span\x18\x0b \x01(\x0b\x32\x10.rappel.ast.SpanB\x06\n\x04kind\"\x7f\n\x07Literal\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x11\n\x07is_none\x18\x05 \x01(\x08H\x00\x42\x07\n\x05value\"\x18\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\"s\n\x08\x42inaryOp\x12\x1e\n\x04left\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12&\n\x02op\x18\x02 \x01(\x0e\x32\x1a.rappel.ast.BinaryOperator\x12\x1f\n\x05right\x18\x03 \x01(\x0b\x32\x10.rappel.ast.Expr\"S\n\x07UnaryOp\x12%\n\x02op\x18\x01 \x01(\x0e\x32\x19.rappel.ast.UnaryOperator\x12!\n\x07operand\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\".\n\x08ListExpr\x12\"\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x10.rappel.ast.Expr\"2\n\x08\x44ictExpr\x12&\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x15.rappel.ast.DictEntry\"K\n\tDictEntry\x12\x1d\n\x03key\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\"P\n\x0bIndexAccess\x12 \n\x06object\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x1f\n\x05index\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\"@\n\tDotAccess\x12 \n\x06object\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x11\n\tattribute\x18\x02 \x01(\t\"\x94\x01\n\x0c\x46unctionCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x10.rappel.ast.Expr\x12!\n\x06kwargs\x18\x03 \x03(\x0b\x32\x11.rappel.ast.Kwarg\x12\x33\n\x0fglobal_function\x18\x04 \x01(\x0e\x32\x1a.rappel.ast.GlobalFunction\"6\n\x05Kwarg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.rappel.ast.Expr\"/\n\x0cParallelExpr\x12\x1f\n\x05\x63\x61lls\x18\x01 \x03(\x0b\x32\x10.rappel.ast.Call\"l\n\nSpreadExpr\x12$\n\ncollection\x18\x01 \x01(\x0b\x32\x10.rappel.ast.Expr\x12\x10\n\x08loop_var\x18\x02 \x01(\t\x12&\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x16.rappel.ast.ActionCall\"o\n\rPolicyBracket\x12(\n\x05retry\x18\x01 \x01(\x0b\x32\x17.rappel.ast.RetryPolicyH\x00\x12,\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.rappel.ast.TimeoutPolicyH\x00\x42\x06\n\x04kind\"b\n\x0bRetryPolicy\x12\x17\n\x0f\x65xception_types\x18\x01 \x03(\t\x12\x13\n\x0bmax_retries\x18\x02 \x01(\r\x12%\n\x07\x62\x61\x63koff\x18\x03 \x01(\x0b\x32\x14.rappel.ast.Duration\"6\n\rTimeoutPolicy\x12%\n\x07timeout\x18\x01 \x01(\x0b\x32\x14.rappel.ast.Duration\"\x1b\n\x08\x44uration\x12\x0f\n\x07seconds\x18\x01 \x01(\x04\"P\n\x04Span\x12\x12\n\nstart_line\x18\x01 \x01(\r\x12\x11\n\tstart_col\x18\x02 \x01(\r\x12\x10\n\x08\x65nd_line\x18\x03 \x01(\r\x12\x0f\n\x07\x65nd_col\x18\x04 \x01(\r*\xdc\x02\n\x0e\x42inaryOperator\x12\x19\n\x15\x42INARY_OP_UNSPECIFIED\x10\x00\x12\x11\n\rBINARY_OP_ADD\x10\x01\x12\x11\n\rBINARY_OP_SUB\x10\x02\x12\x11\n\rBINARY_OP_MUL\x10\x03\x12\x11\n\rBINARY_OP_DIV\x10\x04\x12\x17\n\x13\x42INARY_OP_FLOOR_DIV\x10\x05\x12\x11\n\rBINARY_OP_MOD\x10\x06\x12\x10\n\x0c\x42INARY_OP_EQ\x10\n\x12\x10\n\x0c\x42INARY_OP_NE\x10\x0b\x12\x10\n\x0c\x42INARY_OP_LT\x10\x0c\x12\x10\n\x0c\x42INARY_OP_LE\x10\r\x12\x10\n\x0c\x42INARY_OP_GT\x10\x0e\x12\x10\n\x0c\x42INARY_OP_GE\x10\x0f\x12\x10\n\x0c\x42INARY_OP_IN\x10\x10\x12\x14\n\x10\x42INARY_OP_NOT_IN\x10\x11\x12\x11\n\rBINARY_OP_AND\x10\x14\x12\x10\n\x0c\x42INARY_OP_OR\x10\x15*M\n\rUnaryOperator\x12\x18\n\x14UNARY_OP_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNARY_OP_NEG\x10\x01\x12\x10\n\x0cUNARY_OP_NOT\x10\x02*\xa5\x01\n\x0eGlobalFunction\x12\x1f\n\x1bGLOBAL_FUNCTION_UNSPECIFIED\x10\x00\x12\x19\n\x15GLOBAL_FUNCTION_RANGE\x10\x01\x12\x17\n\x13GLOBAL_FUNCTION_LEN\x10\x02\x12\x1d\n\x19GLOBAL_FUNCTION_ENUMERATE\x10\x03\x12\x1f\n\x1bGLOBAL_FUNCTION_ISEXCEPTION\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ast_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BINARYOPERATOR']._serialized_start=4547
  _globals['_BINARYOPERATOR']._serialized_end=4895
  _globals['_UNARYOPERATOR']._serialized_start=4897
  _globals['_UNARYOPERATOR']._serialized_end=4974
  _globals['_GLOBALFUNCTION']._serialized_start=4977
  _globals['_GLOBALFUNCTION']._serialized_end=5142
  _globals['_PROGRAM']._serialized_start=25
  _globals['_PROGRAM']._serialized_end=78
  _globals['_FUNCTIONDEF']._serialized_start=80
  _globals['_FUNCTIONDEF']._serialized_end=204
  _globals['_IODECL']._serialized_start=206
  _globals['_IODECL']._serialized_end=279
  _globals['_BLOCK']._serialized_start=281
  _globals['_BLOCK']._serialized_end=363
  _globals['_STATEMENT']._serialized_start=366
  _globals['_STATEMENT']._serialized_end=979
  _globals['_BREAKSTMT']._serialized_start=981
  _globals['_BREAKSTMT']._serialized_end=992
  _globals['_CONTINUESTMT']._serialized_start=994
  _globals['_CONTINUESTMT']._serialized_end=1008
  _globals['_ASSIGNMENT']._serialized_start=1010
  _globals['_ASSIGNMENT']._serialized_end=1072
  _globals['_ACTIONCALL']._serialized_start=1075
  _globals['_ACTIONCALL']._serialized_end=1230
  _globals['_SPREADACTION']._serialized_start=1232
  _globals['_SPREADACTION']._serialized_end=1342
  _globals['_PARALLELBLOCK']._serialized_start=1344
  _globals['_PARALLELBLOCK']._serialized_end=1392
  _globals['_CALL']._serialized_start=1394
  _globals['_CALL']._serialized_end=1496
  _globals['_FORLOOP']._serialized_start=1498
  _globals['_FORLOOP']._serialized_end=1601
  _globals['_WHILELOOP']._serialized_start=1603
  _globals['_WHILELOOP']._serialized_end=1690
  _globals['_CONDITIONAL']._serialized_start=1693
  _globals['_CONDITIONAL']._serialized_end=1860
  _globals['_IFBRANCH']._serialized_start=1862
  _globals['_IFBRANCH']._serialized_end=1980
  _globals['_ELIFBRANCH']._serialized_start=1982
  _globals['_ELIFBRANCH']._serialized_end=2102
  _globals['_ELSEBRANCH']._serialized_start=2104
  _globals['_ELSEBRANCH']._serialized_end=2187
  _globals['_TRYEXCEPT']._serialized_start=2189
  _globals['_TRYEXCEPT']._serialized_end=2283
  _globals['_EXCEPTHANDLER']._serialized_start=2286
  _globals['_EXCEPTHANDLER']._serialized_end=2443
  _globals['_RETURNSTMT']._serialized_start=2445
  _globals['_RETURNSTMT']._serialized_end=2505
  _globals['_EXPRSTMT']._serialized_start=2507
  _globals['_EXPRSTMT']._serialized_end=2549
  _globals['_EXPR']._serialized_start=2552
  _globals['_EXPR']._serialized_end=3116
  _globals['_LITERAL']._serialized_start=3118
  _globals['_LITERAL']._serialized_end=3245
  _globals['_VARIABLE']._serialized_start=3247
  _globals['_VARIABLE']._serialized_end=3271
  _globals['_BINARYOP']._serialized_start=3273
  _globals['_BINARYOP']._serialized_end=3388
  _globals['_UNARYOP']._serialized_start=3390
  _globals['_UNARYOP']._serialized_end=3473
  _globals['_LISTEXPR']._serialized_start=3475
  _globals['_LISTEXPR']._serialized_end=3521
  _globals['_DICTEXPR']._serialized_start=3523
  _globals['_DICTEXPR']._serialized_end=3573
  _globals['_DICTENTRY']._serialized_start=3575
  _globals['_DICTENTRY']._serialized_end=3650
  _globals['_INDEXACCESS']._serialized_start=3652
  _globals['_INDEXACCESS']._serialized_end=3732
  _globals['_DOTACCESS']._serialized_start=3734
  _globals['_DOTACCESS']._serialized_end=3798
  _globals['_FUNCTIONCALL']._serialized_start=3801
  _globals['_FUNCTIONCALL']._serialized_end=3949
  _globals['_KWARG']._serialized_start=3951
  _globals['_KWARG']._serialized_end=4005
  _globals['_PARALLELEXPR']._serialized_start=4007
  _globals['_PARALLELEXPR']._serialized_end=4054
  _globals['_SPREADEXPR']._serialized_start=4056
  _globals['_SPREADEXPR']._serialized_end=4164
  _globals['_POLICYBRACKET']._serialized_start=4166
  _globals['_POLICYBRACKET']._serialized_end=4277
  _globals['_RETRYPOLICY']._serialized_start=4279
  _globals['_RETRYPOLICY']._serialized_end=4377
  _globals['_TIMEOUTPOLICY']._serialized_start=4379
  _globals['_TIMEOUTPOLICY']._serialized_end=4433
  _globals['_DURATION']._serialized_start=4435
  _globals['_DURATION']._serialized_end=4462
  _globals['_SPAN']._serialized_start=4464
  _globals['_SPAN']._serialized_end=4544
# @@protoc_insertion_point(module_scope)
